<?xml version="1.0"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:template match="/">
		<html>
			<head>
				<style type="text/css">
					.encounter {
						margin-top: 100px;
					}
					h1 {
						font-size: 36px;
					}
					h2 {
						font-size: 30px;
					}
					.section {
						padding-left: 20px;
					}
					.section-0 h3 {
						font-size: 20px;
					}
					.section-1 h3 {
						font-size: 18px;
					}
					.section-2 h3 {
						font-size: 16px;
					}
					.section-3 h3 {
						font-size: 14px;
					}
					.section-4 h3 {
						font-size: 14px;
					}
					.section-5 h3 {
						font-size: 14px;
					}
					.section-6 h3 {
						font-size: 14px;
					}
					.section h3 img {
						vertical-align: middle;
					}
					.modes {
						font-size: 14px;
						font-weight: normal;
					}
					.flag {
						font-size: 14px;
						font-weight: normal;
						font-style: italic;
						color: #a00000;
					}
				</style>
			</head>
			<body>
				<xsl:apply-templates />
			</body>
		</html>
	</xsl:template>
	
	<xsl:template match="instance">
		<div class="instance">
			<h1><xsl:value-of select="name"/></h1>

			<p><xsl:value-of select="description"/></p>
			<xsl:apply-templates select="encounter" />
		</div>
	</xsl:template>

	<xsl:template match="encounter">
		<div class="encounter">
			<h2><xsl:value-of select="name"/></h2>

			<p><xsl:value-of select="description"/></p>

			<xsl:apply-templates select="rootsection"/>
		</div>
	</xsl:template>
	
	<xsl:template match="rootsection">
		<div class="rootsection">
			<xsl:apply-templates>
				<xsl:with-param name="depth" select="number(0)"/>
			</xsl:apply-templates>
		</div>
	</xsl:template>
	
	<xsl:template match="section">
		<xsl:param name="depth" select="number(0)"/>
		<div>
			<xsl:attribute name="class">
				section section-<xsl:value-of select="$depth"/>
			</xsl:attribute>

			<h3>
				<xsl:if test="@abilityIcon">
					<img>
						<xsl:attribute name="src"><!--
							-->http://static.wowhead.com/images/wow/icons/medium/<xsl:value-of select="translate(substring(@abilityIcon,17,string-length(@abilityIcon)-17-3),'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')"/>.jpg<!--
						--></xsl:attribute>
					</img>
					<xsl:text> </xsl:text>
				</xsl:if>
				<xsl:value-of select="title"/>
				<xsl:text> </xsl:text>
				<xsl:if test="@flag_tank"><span class="flag"><img src="http://wow.zamimg.com/images/icons/ej-tank.png"/> </span></xsl:if>
				<xsl:if test="@flag_dps"><span class="flag"><img src="http://wow.zamimg.com/images/icons/ej-dps.png"/> </span></xsl:if>
				<xsl:if test="@flag_healer"><span class="flag"><img src="http://wow.zamimg.com/images/icons/ej-healer.png"/> </span></xsl:if>
				<xsl:if test="@flag_heroic"><span class="flag"><img src="http://wow.zamimg.com/images/icons/ej-heroic.png"/> </span></xsl:if>
				<xsl:if test="@flag_deadly"><span class="flag"><img src="http://wow.zamimg.com/images/icons/ej-deadly.png"/> </span></xsl:if>
				<xsl:if test="@flag_important"><span class="flag"><img src="http://wow.zamimg.com/images/icons/ej-important.png"/> </span></xsl:if>
				<xsl:if test="@flag_interruptible"><span class="flag"><img src="http://wow.zamimg.com/images/icons/ej-interrupt.png"/> </span></xsl:if>
				<xsl:if test="@flag_magic"><span class="flag"><img src="http://wow.zamimg.com/images/icons/ej-magic.png"/> </span></xsl:if>
				<xsl:if test="@flag_curse"><span class="flag"><img src="http://wow.zamimg.com/images/icons/ej-curse.png"/> </span></xsl:if>
				<xsl:if test="@flag_poison"><span class="flag"><img src="http://wow.zamimg.com/images/icons/ej-poison.png"/> </span></xsl:if>
				<xsl:if test="@flag_disease"><span class="flag"><img src="http://wow.zamimg.com/images/icons/ej-disease.png"/> </span></xsl:if>
				<xsl:if test="@flag_enrage"><span class="flag"><img src="http://wow.zamimg.com/images/icons/ej-enrage.png"/> </span></xsl:if>
				<xsl:if test="@modes"><span class="modes">(<xsl:value-of select="@modes"/>)</span></xsl:if>
			</h3>
	
			<p><xsl:apply-templates select="description"/></p>

			<xsl:apply-templates select="section">
				<xsl:with-param name="depth" select="$depth + 1"/>
			</xsl:apply-templates>
		</div>
	</xsl:template>	
	
	<xsl:template match="description"><xsl:apply-templates/></xsl:template>
	
	<xsl:template match="icon"><xsl:if test="@src='Interface\EncounterJournal\UI-EJ-WarningTextIcon'"><img src="http://wowimg.zamimg.com/images/ui/UI-EJ-WarningTextIcon.png"/> </xsl:if></xsl:template>
	<xsl:template match="color">
		<span>
			<xsl:attribute name="style">
				color: <xsl:value-of select="@color"/>
			</xsl:attribute>
			<xsl:apply-templates/>
		</span>
	</xsl:template>
	
	<xsl:template match="text()" name="insertBreaks">
		<xsl:param name="pText" select="."/>
		<xsl:choose>
			<xsl:when test="not(contains($pText, '&#xA;'))">
				<xsl:copy-of select="$pText"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="substring-before($pText, '&#xA;')"/>
				<br />
				<xsl:call-template name="insertBreaks">
					<xsl:with-param name="pText" select="substring-after($pText, '&#xA;')"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

</xsl:stylesheet>